==> ant-design__icons-1.2.1.jar: META-INF/resources/webjars/ant-design__icons/1.2.1/lib/manifest.js <==
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    fill: [
        'account-book',
        'alert',
        'alipay-circle',
        'alipay-square',
        'aliwangwang',
        'amazon-circle',
        'amazon-square',
        'android',
        'api',
        'apple',
        'appstore',
        'audio',
        'backward',
        'bank',
        'behance-circle',
        'behance-square',
        'bell',
        'book',
        'build',
        'box-plot',
        'bulb',
        'calculator',
        'calendar',
        'car',
        'camera',
        'caret-down',
        'caret-left',
        'caret-right',
        'caret-up',
        'carry-out',
        'check-circle',
        'check-square',
        'chrome',
        'ci-circle',
        'clock-circle',
        'close-circle',
        'close-square',
        'cloud',
        'code-sandbox-circle',
        'code-sandbox-square',
        'code',
        'codepen-circle',
        'codepen-square',
        'compass',
        'contacts',
        'container',
        'control',
        'copy',
        'copyright-circle',
        'credit-card',
        'crown',
        'customer-service',
        'dashboard',
        'database',
        'delete',
        'diff',
        'dingtalk-circle',
        'dingtalk-square',
        'dislike',
        'dollar-circle',
        'down-circle',
        'down-square',
        'dribbble-circle',
        'dribbble-square',
        'dropbox-circle',
        'dropbox-square',
        'edit',
        'environment',
        'euro-circle',
        'exclamation-circle',
        'experiment',
        'eye-invisible',
        'eye',
        'facebook',
        'fast-backward',
        'fast-forward',
        'file-add',
        'file-excel',
        'file-exclamation',
        'file-image',
        'file-pdf',
        'file-markdown',
        'file-ppt',
        'file-text',
        'file-unknown',
        'file-word',
        'file-zip',
        'file',
        'filter',
        'fire',
        'flag',
        'folder-add',
        'folder-open',
        'folder',
        'forward',
        'frown',
        'fund',
        'funnel-plot',
        'gift',
        'github',
        'gitlab',
        'golden',
        'google-circle',
        'google-plus-circle',
        'google-plus-square',
        'hdd',
        'google-square',
        'heart',
        'highlight',
        'home',
        'hourglass',
        'html5',
        'idcard',
        'ie-circle',
        'ie-square',
        'info-circle',
        'instagram',
        'insurance',
        'interation',
        'left-circle',
        'left-square',
        'layout',
        'like',
        'linkedin',
        'lock',
        'mail',
        'medicine-box',
        'medium-circle',
        'medium-square',
        'meh',
        'message',
        'minus-circle',
        'minus-square',
        'mobile',
        'money-collect',
        'notification',
        'pause-circle',
        'pay-circle',
        'phone',
        'picture',
        'pie-chart',
        'play-circle',
        'play-square',
        'plus-circle',
        'pound-circle',
        'profile',
        'plus-square',
        'project',
        'printer',
        'property-safety',
        'pushpin',
        'qq-circle',
        'qq-square',
        'question-circle',
        'read',
        'reconciliation',
        'red-envelope',
        'reddit-circle',
        'reddit-square',
        'rest',
        'right-circle',
        'right-square',
        'rocket',
        'safety-certificate',
        'save',
        'schedule',
        'security-scan',
        'setting',
        'shop',
        'shopping',
        'sketch-circle',
        'sketch-square',
        'skin',
        'skype',
        'slack-circle',
        'slack-square',
        'sliders',
        'smile',
        'snippets',
        'sound',
        'star',
        'step-backward',
        'step-forward',
        'stop',
        'switcher',
        'tablet',
        'tag',
        'tags',
        'taobao-circle',
        'taobao-square',
        'thunderbolt',
        'tool',
        'trademark-circle',
        'trophy',
        'twitter-circle',
        'twitter-square',
        'unlock',
        'up-circle',
        'up-square',
        'usb',
        'video-camera',
        'wallet',
        'warning',
        'wechat',
        'weibo-circle',
        'weibo-square',
        'windows',
        'yahoo',
        'youtube',
        'yuque',
        'zhihu-circle',
        'zhihu-square'
    ],
    outline: [
        'account-book',
        'alert',
        'alipay-circle',
        'aliwangwang',
        'android',
        'api',
        'apple',
        'appstore',
        'audio',
        'backward',
        'bank',
        'behance-square',
        'bell',
        'book',
        'build',
        'box-plot',
        'bulb',
        'calculator',
        'calendar',
        'car',
        'camera',
        'caret-down',
        'caret-left',
        'caret-right',
        'caret-up',
        'carry-out',
        'check-circle',
        'check-square',
        'chrome',
        'clock-circle',
        'close-circle',
        'close-square',
        'cloud',
        'code',
        'codepen-circle',
        'compass',
        'contacts',
        'container',
        'control',
        'copy',
        'credit-card',
        'crown',
        'customer-service',
        'dashboard',
        'database',
        'delete',
        'diff',
        'dislike',
        'down-circle',
        'down-square',
        'dribbble-square',
        'edit',
        'environment',
        'exclamation-circle',
        'experiment',
        'eye-invisible',
        'eye',
        'facebook',
        'fast-backward',
        'fast-forward',
        'file-add',
        'file-excel',
        'file-exclamation',
        'file-image',
        'file-pdf',
        'file-markdown',
        'file-ppt',
        'file-text',
        'file-unknown',
        'file-word',
        'file-zip',
        'file',
        'filter',
        'fire',
        'flag',
        'folder-add',
        'folder-open',
        'folder',
        'forward',
        'frown',
        'fund',
        'funnel-plot',
        'gift',
        'github',
        'gitlab',
        'hdd',
        'heart',
        'highlight',
        'home',
        'hourglass',
        'html5',
        'idcard',
        'info-circle',
        'instagram',
        'insurance',
        'interation',
        'left-circle',
        'left-square',
        'layout',
        'like',
        'linkedin',
        'lock',
        'mail',
        'medicine-box',
        'meh',
        'message',
        'minus-circle',
        'minus-square',
        'mobile',
        'money-collect',
        'notification',
        'pause-circle',
        'pay-circle',
        'phone',
        'picture',
        'pie-chart',
        'play-circle',
        'play-square',
        'plus-circle',
        'profile',
        'plus-square',
        'project',
        'printer',
        'property-safety',
        'pushpin',
        'question-circle',
        'read',
        'reconciliation',
        'red-envelope',
        'rest',
        'right-circle',
        'right-square',
        'rocket',
        'safety-certificate',
        'save',
        'schedule',
        'security-scan',
        'setting',
        'shop',
        'shopping',
        'skin',
        'skype',
        'slack-square',
        'sliders',
        'smile',
        'snippets',
        'sound',
        'star',
        'step-backward',
        'step-forward',
        'stop',
        'switcher',
        'tablet',
        'tag',
        'tags',
        'taobao-circle',
        'thunderbolt',
        'tool',
        'trophy',
        'unlock',
        'up-circle',
        'up-square',
        'usb',
        'video-camera',
        'wallet',
        'warning',
        'wechat',
        'weibo-circle',
        'weibo-square',
        'windows',
        'yahoo',
        'youtube',
        'yuque',
        'alibaba',
        'align-center',
        'align-left',
        'align-right',
        'alipay',
        'aliyun',
        'amazon',
        'ant-cloud',
        'ant-design',
        'apartment',
        'area-chart',
        'arrow-left',
        'arrow-right',
        'arrow-up',
        'arrows-alt',
        'audit',
        'arrow-down',
        'bar-chart',
        'barcode',
        'bars',
        'behance',
        'bg-colors',
        'block',
        'bold',
        'border-horizontal',
        'border-bottom',
        'border-inner',
        'border-left',
        'border-outer',
        'border-right',
        'border-top',
        'border-verticle',
        'border',
        'branches',
        'check',
        'ci',
        'close',
        'cloud-download',
        'cloud-server',
        'cloud-sync',
        'cloud-upload',
        'cluster',
        'code-sandbox',
        'codepen',
        'coffee',
        'colum-height',
        'column-width',
        'copyright',
        'dash',
        'deployment-unit',
        'desktop',
        'dingding',
        'disconnect',
        'dollar',
        'dot-chart',
        'double-left',
        'double-right',
        'down',
        'download',
        'drag',
        'dribbble',
        'dropbox',
        'ellipsis',
        'enter',
        'euro',
        'exception',
        'exclamation',
        'export',
        'fall',
        'file-done',
        'file-jpg',
        'file-protect',
        'file-search',
        'file-sync',
        'font-colors',
        'font-size',
        'fork',
        'form',
        'fullscreen-exit',
        'fullscreen',
        'gateway',
        'global',
        'gold',
        'google-plus',
        'google',
        'heat-map',
        'ie',
        'import',
        'inbox',
        'info',
        'issues-close',
        'italic',
        'key',
        'laptop',
        'left',
        'line-chart',
        'line-height',
        'line',
        'link',
        'loading-3-quarters',
        'loading',
        'login',
        'logout',
        'man',
        'medium-workmark',
        'medium',
        'menu-fold',
        'menu-unfold',
        'menu',
        'minus',
        'monitor',
        'more',
        'mr',
        'number',
        'ordered-list',
        'paper-clip',
        'pause',
        'percentage',
        'pic-center',
        'pic-left',
        'pic-right',
        'plus',
        'pound',
        'poweroff',
        'qq',
        'qrcode',
        'question',
        'radar-chart',
        'radius-bottomleft',
        'radius-bottomright',
        'radius-setting',
        'radius-upleft',
        'radius-upright',
        'reddit',
        'redo',
        'reload-time',
        'reload',
        'retweet',
        'right',
        'rise',
        'robot',
        'rollback',
        'safety',
        'scan',
        'scissor',
        'search',
        'select',
        'shake',
        'share-alt',
        'shopping-cart',
        'shrink',
        'sketch',
        'slack',
        'small-dash',
        'solution',
        'sort-ascending',
        'sort-descending',
        'stock',
        'strikethrough',
        'swap-left',
        'swap-right',
        'swap',
        'sync',
        'table',
        'taobao',
        'team',
        'to-top',
        'trademark',
        'transaction',
        'twitter',
        'underline',
        'undo',
        'unordered-list',
        'up',
        'upload',
        'user-add',
        'user-delete',
        'user',
        'usergroup-add',
        'usergroup-delete',
        'vertical-align-bottom',
        'vertical-align-middle',
        'vertical-align-top',
        'vertical-left',
        'vertical-right',
        'weibo',
        'wifi',
        'woman',
        'zhihu',
        'zoom-in',
        'zoom-out'
    ],
    twotone: [
        'account-book',
        'alert',
        'api',
        'appstore',
        'audio',
        'bank',
        'bell',
        'book',
        'build',
        'box-plot',
        'bulb',
        'calculator',
        'car',
        'camera',
        'carry-out',
        'check-circle',
        'check-square',
        'clock-circle',
        'close-circle',
        'close-square',
        'cloud',
        'code',
        'compass',
        'contacts',
        'container',
        'control',
        'copy',
        'credit-card',
        'crown',
        'customer-service',
        'dashboard',
        'database',
        'delete',
        'diff',
        'dislike',
        'down-circle',
        'down-square',
        'edit',
        'environment',
        'exclamation-circle',
        'experiment',
        'eye-invisible',
        'eye',
        'file-add',
        'file-excel',
        'file-exclamation',
        'file-image',
        'file-pdf',
        'file-markdown',
        'file-ppt',
        'file-text',
        'file-unknown',
        'file-word',
        'file-zip',
        'file',
        'filter',
        'fire',
        'flag',
        'folder-add',
        'folder-open',
        'folder',
        'frown',
        'fund',
        'funnel-plot',
        'gift',
        'hdd',
        'heart',
        'highlight',
        'home',
        'hourglass',
        'html5',
        'idcard',
        'info-circle',
        'insurance',
        'interation',
        'left-circle',
        'left-square',
        'layout',
        'like',
        'lock',
        'mail',
        'medicine-box',
        'meh',
        'message',
        'minus-circle',
        'minus-square',
        'mobile',
        'money-collect',
        'notification',
        'pause-circle',
        'phone',
        'picture',
        'pie-chart',
        'play-circle',
        'play-square',
        'plus-circle',
        'pound-circle',
        'profile',
        'plus-square',
        'project',
        'printer',
        'property-safety',
        'pushpin',
        'question-circle',
        'reconciliation',
        'red-envelope',
        'rest',
        'right-circle',
        'right-square',
        'rocket',
        'safety-certificate',
        'save',
        'schedule',
        'security-scan',
        'setting',
        'shop',
        'shopping',
        'skin',
        'sliders',
        'smile',
        'snippets',
        'sound',
        'star',
        'stop',
        'switcher',
        'tablet',
        'tag',
        'tags',
        'thunderbolt',
        'tool',
        'trademark-circle',
        'trophy',
        'unlock',
        'up-circle',
        'up-square',
        'usb',
        'video-camera',
        'wallet',
        'warning',
        'ci',
        'copyright',
        'dollar',
        'euro',
        'gold',
        'canlendar'
    ]
};

==> ant-design__icons-2.1.1.jar: META-INF/resources/webjars/ant-design__icons/2.1.1/lib/manifest.js <==
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    fill: [
        'account-book',
        'alert',
        'alipay-circle',
        'alipay-square',
        'aliwangwang',
        'amazon-circle',
        'android',
        'amazon-square',
        'api',
        'appstore',
        'audio',
        'apple',
        'backward',
        'bank',
        'behance-circle',
        'bell',
        'behance-square',
        'book',
        'box-plot',
        'bug',
        'bulb',
        'calculator',
        'build',
        'calendar',
        'camera',
        'car',
        'caret-down',
        'caret-left',
        'caret-right',
        'carry-out',
        'caret-up',
        'check-circle',
        'check-square',
        'chrome',
        'ci-circle',
        'clock-circle',
        'close-circle',
        'cloud',
        'close-square',
        'code-sandbox-square',
        'code-sandbox-circle',
        'code',
        'codepen-circle',
        'compass',
        'codepen-square',
        'contacts',
        'container',
        'control',
        'copy',
        'copyright-circle',
        'credit-card',
        'crown',
        'customer-service',
        'dashboard',
        'delete',
        'diff',
        'dingtalk-circle',
        'database',
        'dingtalk-square',
        'dislike',
        'dollar-circle',
        'down-circle',
        'down-square',
        'dribbble-circle',
        'dribbble-square',
        'dropbox-circle',
        'dropbox-square',
        'environment',
        'edit',
        'exclamation-circle',
        'euro-circle',
        'experiment',
        'eye-invisible',
        'eye',
        'facebook',
        'fast-backward',
        'fast-forward',
        'file-add',
        'file-excel',
        'file-exclamation',
        'file-image',
        'file-markdown',
        'file-pdf',
        'file-ppt',
        'file-text',
        'file-unknown',
        'file-word',
        'file-zip',
        'file',
        'filter',
        'fire',
        'flag',
        'folder-add',
        'folder',
        'folder-open',
        'forward',
        'frown',
        'fund',
        'funnel-plot',
        'gift',
        'github',
        'gitlab',
        'golden',
        'google-circle',
        'google-plus-circle',
        'google-plus-square',
        'google-square',
        'hdd',
        'heart',
        'highlight',
        'home',
        'hourglass',
        'html5',
        'idcard',
        'ie-circle',
        'ie-square',
        'info-circle',
        'instagram',
        'insurance',
        'interaction',
        'interation',
        'layout',
        'left-circle',
        'left-square',
        'like',
        'linkedin',
        'lock',
        'mail',
        'medicine-box',
        'medium-circle',
        'medium-square',
        'meh',
        'message',
        'minus-circle',
        'minus-square',
        'mobile',
        'money-collect',
        'pause-circle',
        'pay-circle',
        'notification',
        'phone',
        'picture',
        'pie-chart',
        'play-circle',
        'play-square',
        'plus-circle',
        'plus-square',
        'pound-circle',
        'printer',
        'profile',
        'project',
        'pushpin',
        'property-safety',
        'qq-circle',
        'qq-square',
        'question-circle',
        'read',
        'reconciliation',
        'red-envelope',
        'reddit-circle',
        'reddit-square',
        'rest',
        'right-circle',
        'rocket',
        'right-square',
        'safety-certificate',
        'save',
        'schedule',
        'security-scan',
        'setting',
        'shop',
        'shopping',
        'sketch-circle',
        'sketch-square',
        'skin',
        'slack-circle',
        'skype',
        'slack-square',
        'sliders',
        'smile',
        'snippets',
        'sound',
        'star',
        'step-backward',
        'step-forward',
        'stop',
        'switcher',
        'tablet',
        'tag',
        'tags',
        'taobao-circle',
        'taobao-square',
        'tool',
        'thunderbolt',
        'trademark-circle',
        'twitter-circle',
        'trophy',
        'twitter-square',
        'unlock',
        'up-circle',
        'up-square',
        'usb',
        'video-camera',
        'wallet',
        'warning',
        'wechat',
        'weibo-circle',
        'windows',
        'yahoo',
        'weibo-square',
        'yuque',
        'youtube',
        'zhihu-circle',
        'zhihu-square'
    ],
    outline: [
        'account-book',
        'alert',
        'alipay-circle',
        'aliwangwang',
        'android',
        'api',
        'appstore',
        'audio',
        'apple',
        'backward',
        'bank',
        'bell',
        'behance-square',
        'book',
        'box-plot',
        'bug',
        'bulb',
        'calculator',
        'build',
        'calendar',
        'camera',
        'car',
        'caret-down',
        'caret-left',
        'caret-right',
        'carry-out',
        'caret-up',
        'check-circle',
        'check-square',
        'chrome',
        'clock-circle',
        'close-circle',
        'cloud',
        'close-square',
        'code',
        'codepen-circle',
        'compass',
        'contacts',
        'container',
        'control',
        'copy',
        'credit-card',
        'crown',
        'customer-service',
        'dashboard',
        'delete',
        'diff',
        'database',
        'dislike',
        'down-circle',
        'down-square',
        'dribbble-square',
        'environment',
        'edit',
        'exclamation-circle',
        'experiment',
        'eye-invisible',
        'eye',
        'facebook',
        'fast-backward',
        'fast-forward',
        'file-add',
        'file-excel',
        'file-exclamation',
        'file-image',
        'file-markdown',
        'file-pdf',
        'file-ppt',
        'file-text',
        'file-unknown',
        'file-word',
        'file-zip',
        'file',
        'filter',
        'fire',
        'flag',
        'folder-add',
        'folder',
        'folder-open',
        'forward',
        'frown',
        'fund',
        'funnel-plot',
        'gift',
        'github',
        'gitlab',
        'hdd',
        'heart',
        'highlight',
        'home',
        'hourglass',
        'html5',
        'idcard',
        'info-circle',
        'instagram',
        'insurance',
        'interaction',
        'interation',
        'layout',
        'left-circle',
        'left-square',
        'like',
        'linkedin',
        'lock',
        'mail',
        'medicine-box',
        'meh',
        'message',
        'minus-circle',
        'minus-square',
        'mobile',
        'money-collect',
        'pause-circle',
        'pay-circle',
        'notification',
        'phone',
        'picture',
        'pie-chart',
        'play-circle',
        'play-square',
        'plus-circle',
        'plus-square',
        'printer',
        'profile',
        'project',
        'pushpin',
        'property-safety',
        'question-circle',
        'read',
        'reconciliation',
        'red-envelope',
        'rest',
        'right-circle',
        'rocket',
        'right-square',
        'safety-certificate',
        'save',
        'schedule',
        'security-scan',
        'setting',
        'shop',
        'shopping',
        'skin',
        'skype',
        'slack-square',
        'sliders',
        'smile',
        'snippets',
        'sound',
        'star',
        'step-backward',
        'step-forward',
        'stop',
        'switcher',
        'tablet',
        'tag',
        'tags',
        'taobao-circle',
        'tool',
        'thunderbolt',
        'trophy',
        'unlock',
        'up-circle',
        'up-square',
        'usb',
        'video-camera',
        'wallet',
        'warning',
        'wechat',
        'weibo-circle',
        'windows',
        'yahoo',
        'weibo-square',
        'yuque',
        'youtube',
        'alibaba',
        'align-center',
        'align-left',
        'align-right',
        'alipay',
        'aliyun',
        'amazon',
        'ant-cloud',
        'apartment',
        'ant-design',
        'area-chart',
        'arrow-left',
        'arrow-down',
        'arrow-up',
        'arrows-alt',
        'arrow-right',
        'audit',
        'bar-chart',
        'barcode',
        'bars',
        'behance',
        'bg-colors',
        'block',
        'bold',
        'border-bottom',
        'border-left',
        'border-outer',
        'border-inner',
        'border-right',
        'border-horizontal',
        'border-top',
        'border-verticle',
        'border',
        'branches',
        'check',
        'ci',
        'close',
        'cloud-download',
        'cloud-server',
        'cloud-sync',
        'cloud-upload',
        'cluster',
        'codepen',
        'code-sandbox',
        'colum-height',
        'column-width',
        'column-height',
        'coffee',
        'copyright',
        'dash',
        'deployment-unit',
        'desktop',
        'dingding',
        'disconnect',
        'dollar',
        'double-left',
        'dot-chart',
        'double-right',
        'down',
        'drag',
        'download',
        'dribbble',
        'dropbox',
        'ellipsis',
        'enter',
        'euro',
        'exception',
        'exclamation',
        'export',
        'fall',
        'file-done',
        'file-jpg',
        'file-protect',
        'file-sync',
        'file-search',
        'font-colors',
        'font-size',
        'fork',
        'form',
        'fullscreen-exit',
        'fullscreen',
        'gateway',
        'global',
        'google-plus',
        'gold',
        'google',
        'heat-map',
        'history',
        'ie',
        'import',
        'inbox',
        'info',
        'italic',
        'key',
        'issues-close',
        'laptop',
        'left',
        'line-chart',
        'link',
        'line-height',
        'line',
        'loading-3-quarters',
        'loading',
        'login',
        'logout',
        'man',
        'medium',
        'medium-workmark',
        'menu-unfold',
        'menu-fold',
        'menu',
        'minus',
        'monitor',
        'more',
        'ordered-list',
        'number',
        'pause',
        'percentage',
        'paper-clip',
        'pic-center',
        'pic-left',
        'pic-right',
        'plus',
        'pound',
        'poweroff',
        'pull-request',
        'qq',
        'question',
        'radar-chart',
        'qrcode',
        'radius-bottomleft',
        'radius-bottomright',
        'radius-upleft',
        'radius-setting',
        'radius-upright',
        'reddit',
        'redo',
        'reload',
        'retweet',
        'right',
        'rise',
        'rollback',
        'safety',
        'robot',
        'scan',
        'search',
        'scissor',
        'select',
        'shake',
        'share-alt',
        'shopping-cart',
        'shrink',
        'sketch',
        'slack',
        'small-dash',
        'solution',
        'sort-descending',
        'sort-ascending',
        'stock',
        'swap-left',
        'swap-right',
        'strikethrough',
        'swap',
        'sync',
        'table',
        'team',
        'taobao',
        'to-top',
        'trademark',
        'transaction',
        'twitter',
        'underline',
        'undo',
        'unordered-list',
        'up',
        'upload',
        'user-add',
        'user-delete',
        'usergroup-add',
        'user',
        'usergroup-delete',
        'vertical-align-bottom',
        'vertical-align-middle',
        'vertical-align-top',
        'vertical-left',
        'vertical-right',
        'weibo',
        'wifi',
        'zhihu',
        'woman',
        'zoom-out',
        'zoom-in'
    ],
    twotone: [
        'account-book',
        'alert',
        'api',
        'appstore',
        'audio',
        'bank',
        'bell',
        'book',
        'box-plot',
        'bug',
        'bulb',
        'calculator',
        'build',
        'calendar',
        'camera',
        'car',
        'carry-out',
        'check-circle',
        'check-square',
        'clock-circle',
        'close-circle',
        'cloud',
        'close-square',
        'code',
        'compass',
        'contacts',
        'container',
        'control',
        'copy',
        'credit-card',
        'crown',
        'customer-service',
        'dashboard',
        'delete',
        'diff',
        'database',
        'dislike',
        'down-circle',
        'down-square',
        'environment',
        'edit',
        'exclamation-circle',
        'experiment',
        'eye-invisible',
        'eye',
        'file-add',
        'file-excel',
        'file-exclamation',
        'file-image',
        'file-markdown',
        'file-pdf',
        'file-ppt',
        'file-text',
        'file-unknown',
        'file-word',
        'file-zip',
        'file',
        'filter',
        'fire',
        'flag',
        'folder-add',
        'folder',
        'folder-open',
        'frown',
        'fund',
        'funnel-plot',
        'gift',
        'hdd',
        'heart',
        'highlight',
        'home',
        'hourglass',
        'html5',
        'idcard',
        'info-circle',
        'insurance',
        'interaction',
        'interation',
        'layout',
        'left-circle',
        'left-square',
        'like',
        'lock',
        'mail',
        'medicine-box',
        'meh',
        'message',
        'minus-circle',
        'minus-square',
        'mobile',
        'money-collect',
        'pause-circle',
        'notification',
        'phone',
        'picture',
        'pie-chart',
        'play-circle',
        'play-square',
        'plus-circle',
        'plus-square',
        'pound-circle',
        'printer',
        'profile',
        'project',
        'pushpin',
        'property-safety',
        'question-circle',
        'reconciliation',
        'red-envelope',
        'rest',
        'right-circle',
        'rocket',
        'right-square',
        'safety-certificate',
        'save',
        'schedule',
        'security-scan',
        'setting',
        'shop',
        'shopping',
        'skin',
        'sliders',
        'smile',
        'snippets',
        'sound',
        'star',
        'stop',
        'switcher',
        'tablet',
        'tag',
        'tags',
        'tool',
        'thunderbolt',
        'trademark-circle',
        'trophy',
        'unlock',
        'up-circle',
        'up-square',
        'usb',
        'video-camera',
        'wallet',
        'warning',
        'ci',
        'copyright',
        'dollar',
        'euro',
        'gold',
        'canlendar'
    ]
};
